@@ -14,7 +14,6 @@ import grpc
 from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
 
 from immudb import grpcutils
-from immudb.grpc.schema_pb2 import OpenSessionResponse
 from immudb.handler import (batchGet, batchSet, changePassword, changePermission, createUser,
                             currentRoot, createDatabase, databaseList, deleteKeys, useDatabase,
                             get, listUsers, sqldescribe, verifiedGet, verifiedSet, setValue, history,
@@ -180,7 +179,7 @@ class ImmudbClient:
             password=convertedPassword,
             databaseName=convertedDatabase
         )
-        self._session_response = schema_pb2_grpc.schema__pb2.OpenSessionResponse = self.__stub.OpenSession(
+        self._session_response = self.__stub.OpenSession(
             req)
         self.__stub = self.set_session_id_interceptor(self._session_response)
         return transaction.Tx(self.__stub, self._session_response, self.channel)
@@ -274,14 +273,14 @@ class ImmudbClient:
         metadata.ExpiresAt(expiresAt)
         return setValue.call(self.__stub, self.__rs, key, value, metadata)
 
-    def get(self, key: bytes):
-        return get.call(self.__stub, self.__rs, key)
+    def get(self, key: bytes, atRevision: int = None):
+        return get.call(self.__stub, self.__rs, key, atRevision=atRevision)
 
     # Not implemented: getSince
     # Not implemented: getAt
 
-    def verifiedGet(self, key: bytes):
-        return verifiedGet.call(self.__stub, self.__rs, key, verifying_key=self.__vk)
+    def verifiedGet(self, key: bytes, atRevision: int = None):
+        return verifiedGet.call(self.__stub, self.__rs, key, verifying_key=self.__vk, atRevision=atRevision)
 
     def verifiedGetSince(self, key: bytes, sinceTx: int):
         return verifiedGet.call(self.__stub, self.__rs, key, sinceTx=sinceTx, verifying_key=self.__vk)
